@@ -1,9 +1,9 @@
 package Dist::Zilla::Plugin::InsertCodeResult;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-21'; # DATE
+our $DATE = '2021-05-21'; # DATE
 our $DIST = 'Dist-Zilla-Plugin-InsertCodeResult'; # DIST
-our $VERSION = '0.053'; # VERSION
+our $VERSION = '0.054'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,10 +33,12 @@ sub munge_file {
     my ($self, $file) = @_;
     my $content_as_bytes = $file->encoded_content;
     if ($content_as_bytes =~ s{
-                                  ^\#\s*CODE:\s*(.*)\s*$ |
+                                  ^\#\s*CODE:\s*(.*)\s*(\R|\z) |
                                   ^\#\s*BEGIN_CODE\s*\R((?:.|\R)*?)^\#\s*END_CODE\s*(?:\R|\z)
                           }{
-                              $self->_code_result($1 // $2)."\n"
+                              my $res = $self->_code_result($1 // $2);
+                              $res .= "\n" unless $res =~ /\R\z/;
+                              $res;
                           }egmx) {
         $self->log(["inserting result of code '%s' in %s", $1 // $2, $file->name]);
         $self->log_debug(["content of %s after code result insertion: '%s'", $file->name, $content_as_bytes]);
@@ -80,7 +82,7 @@ Dist::Zilla::Plugin::InsertCodeResult - Insert the result of Perl code into your
 
 =head1 VERSION
 
-This document describes version 0.053 of Dist::Zilla::Plugin::InsertCodeResult (from Perl distribution Dist-Zilla-Plugin-InsertCodeResult), released on 2021-02-21.
+This document describes version 0.054 of Dist::Zilla::Plugin::InsertCodeResult (from Perl distribution Dist-Zilla-Plugin-InsertCodeResult), released on 2021-05-21.
 
 =head1 SYNOPSIS
 
